==> klayout-0.19.3.tar.gz: klayout-0.19.3/src/contrib/gds2_txt/dbGDS2TextReader.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_dbGDS2ReaderText
#define HDR_dbGDS2ReaderText

#include "dbGDS2Reader.h"
#include <sstream>


namespace db
{
  
/**
 *  @brief Generic base class of GDS2 Text reader exceptions
 */
class GDS2ReaderTextException
  : public ReaderException 
{
public:
  GDS2ReaderTextException (const std::string &msg, size_t n, const std::string &cell)
    : ReaderException (tl::sprintf (tl::translate ("%s (line number=%ld, cell=%s)").c_str (), msg.c_str (),  n, cell.c_str ()))
  { }
};

/**
 *  @brief The GDS2 text format stream reader
 */
class GDS2ReaderText
  : public GDS2ReaderBase
{

public:
  /**
   *  @brief Construct a stream reader object
   *
   *  @param s The stream delegate from which to read stream data from
   */
  GDS2ReaderText(tl::InputStream &s, int _iChunkSize = 1024);

  /**
   *  @brief Destructor
   */
  ~GDS2ReaderText();

  /** 
   *  @brief The basic read method 
   *
   *  This method will read the stream data and translate this to
   *  insert calls into the layout object. This will not do much
   *  on the layout object beside inserting the objects.
   *  It can be given a couple of options specified with the
   *  LoadLayoutOptions object.
   *  The returned map will contain all layers, the passed
   *  ones and the newly created ones.
   *
   *  @param layout The layout object to write to
   *  @param options The generic reader options
   *  @return The LayerMap object that tells where which layer was loaded
   */
  virtual const LayerMap &read (db::Layout &layout, const LoadLayoutOptions &options) throw (tl::Exception);

  /** 
   *  @brief The basic read method (without mapping)
   *
   *  This method will read the stream data and translate this to
   *  insert calls into the layout object. This will not do much
   *  on the layout object beside inserting the objects.
   *  This version will read all input layers and return a map
   *  which tells which GDS2 layer has been read into which logical
   *  layer.
   *
   *  @param layout The layout object to write to
   *  @return The LayerMap object
   */
  virtual const LayerMap &read (db::Layout &layout) throw (tl::Exception);

  /**
   *  @brief Format
   */
  const char *format () const { return "GDS2Text"; }

private:
  std::vector<std::pair<long, long> > aulPoints;
  GDS2XY *pXYData;
  unsigned int uXYLength;

  short siExtactData(std::string &sInput, std::string &sToken, std::string &sArguments);

    /**
   *  @brief Store the aulPoints Vector into the Binary standard structure for reading XY properties
   *  
   */
  void vConvertToStruct();

  /**
   *  @brief provide some initialization, as the text reader is not as stateless as the binary reader
   */
  void vInit(int _iChunkSize);

  tl::InputStream  &sStream;
  std::string      sExtractedValue;
  std::string      sExtractedArguments;
  std::string      sNextLine;
  std::stringstream ssFormattingStream;
  int iGetSize; 
  int m_iNumLine;
  int iNumRead;
  int iChunkSize;
  tl::Progress mProgress;

  const char *get_string () throw (tl::Exception);
  void get_string (tl::string &s) const throw (tl::Exception);
  int get_int () throw (tl::Exception);
  short get_short () throw (tl::Exception);
  unsigned short get_ushort () throw (tl::Exception);
  double get_double()throw (tl::Exception);
  short get_record() throw (tl::Exception);
  short peek_record () throw (tl::Exception);
  GDS2XY *get_xy_data (unsigned int &xy_length) throw (tl::Exception);
  void progress_checkpoint ();
  void error (const std::string &txt) throw (tl::Exception);
  void warn (const std::string &txt);

  /**
   *  @brief append XY datas into the aulpoints vector for later use
   *  
   */
  void vConvertToXY(std::string &_sArg);
};

}
#endif

==> klayout-0.21.5.tar.gz: klayout-0.21.5/src/contrib/gds2_txt/dbGDS2TextReader.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_dbGDS2ReaderText
#define HDR_dbGDS2ReaderText

#include "dbGDS2Reader.h"
#include <sstream>


namespace db
{
  
/**
 *  @brief Generic base class of GDS2 Text reader exceptions
 */
class GDS2ReaderTextException
  : public ReaderException 
{
public:
  GDS2ReaderTextException (const std::string &msg, size_t n, const std::string &cell)
    : ReaderException (tl::sprintf (tl::translate ("%s (line number=%ld, cell=%s)").c_str (), msg.c_str (),  n, cell.c_str ()))
  { }
};

/**
 *  @brief The GDS2 text format stream reader
 */
class GDS2ReaderText
  : public GDS2ReaderBase
{

public:
  /**
   *  @brief Construct a stream reader object
   *
   *  @param s The stream delegate from which to read stream data from
   */
  GDS2ReaderText(tl::InputStreamBase &s, int _iChunkSize = 1024);

  /**
   *  @brief Destructor
   */
  ~GDS2ReaderText();

  /** 
   *  @brief The basic read method 
   *
   *  This method will read the stream data and translate this to
   *  insert calls into the layout object. This will not do much
   *  on the layout object beside inserting the objects.
   *  It can be given a couple of options specified with the
   *  LoadLayoutOptions object.
   *  The returned map will contain all layers, the passed
   *  ones and the newly created ones.
   *
   *  @param layout The layout object to write to
   *  @param options The generic reader options
   *  @return The LayerMap object that tells where which layer was loaded
   */
  virtual const LayerMap &read (db::Layout &layout, const LoadLayoutOptions &options) throw (tl::Exception);

  /** 
   *  @brief The basic read method (without mapping)
   *
   *  This method will read the stream data and translate this to
   *  insert calls into the layout object. This will not do much
   *  on the layout object beside inserting the objects.
   *  This version will read all input layers and return a map
   *  which tells which GDS2 layer has been read into which logical
   *  layer.
   *
   *  @param layout The layout object to write to
   *  @return The LayerMap object
   */
  virtual const LayerMap &read (db::Layout &layout) throw (tl::Exception);

  /**
   *  @brief Format
   */
  const char *format () const { return "GDS2Text"; }

private:
  std::vector<std::pair<long, long> > aulPoints;
  GDS2XY *pXYData;
  unsigned int uXYLength;

  short siExtactData(std::string &sInput, std::string &sToken, std::string &sArguments);

    /**
   *  @brief Store the aulPoints Vector into the Binary standard structure for reading XY properties
   *  
   */
  void vConvertToStruct();

  /**
   *  @brief provide some initialization, as the text reader is not as stateless as the binary reader
   */
  void vInit(int _iChunkSize);

  tl::InputStream  sStream;
  std::string      sExtractedValue;
  std::string      sExtractedArguments;
  std::string      sNextLine;
  std::stringstream ssFormattingStream;
  int iGetSize; 
  int m_iNumLine;
  int iNumRead;
  int iChunkSize;
  tl::Progress mProgress;

  const char *get_string () throw (tl::Exception);
  void get_string (tl::string &s) const throw (tl::Exception);
  int get_int () throw (tl::Exception);
  short get_short () throw (tl::Exception);
  unsigned short get_ushort () throw (tl::Exception);
  double get_double()throw (tl::Exception);
  short get_record() throw (tl::Exception);
  short peek_record () throw (tl::Exception);
  GDS2XY *get_xy_data (unsigned int &xy_length) throw (tl::Exception);
  void progress_checkpoint ();
  void error (const std::string &txt) throw (tl::Exception);
  void warn (const std::string &txt);

  /**
   *  @brief append XY datas into the aulpoints vector for later use
   *  
   */
  void vConvertToXY(std::string &_sArg);
};

}
#endif
